#
# spec file for package wimax-tools
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libwimaxll0
Name:           wimax-tools
Version:        1.4.5
Release:        7.51
Summary:        WiMAX Low Level Tools
License:        BSD-3-Clause
Group:          Productivity/Networking/Other
Url:            http://linuxwimax.org
Source0:        https://github.com/ago/wimax-tools/archive/v%{version}/wimax-tools-%{version}.tar.gz
# PATCH-FEATURE-UPSTREAM build-with-libnl3.patch -- Allow build with libnl3 https://github.com/ago/wimax-tools/pull/2
Patch0:         build-with-libnl3.patch
# PATCH-FIX-OPENSUSE versioned-plugindir.patch -- Install plugins into versioned directory
Patch1:         versioned-plugindir.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libnl-3.0)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Tools for diagnosing and testing WiMAX connectivity.
These tools work at a very low level using the Linux kernel's WiMAX
stack.
This package does not provide high level connectivity support, but
packages that do so might depend on it.

%package devel
Summary:        Development files for WiMAX Low Level Tools
Group:          Development/Libraries/Other
Requires:       %{name} >= %{version}

%description devel
Development support for the WiMAX Low Level Tools.
This package provides the header files and libraries needed to compile
programs that will use the runtime libraries provided by the WiMAX Low
Level Tools.

%package -n %{libname}
Summary:        Runtime libraries for WiMAX Low Level Tools
Group:          System/Libraries

%description -n %{libname}
Runtime libraries for the WiMAX Low Level Tools.
Other applications use these libraries to gain access to the WiMAX
kernel stack.

%prep
%setup -q -n wimax-tools-%{version}
%patch0 -p1
%patch1 -p1

touch NEWS AUTHORS ChangeLog

%build
autoreconf -vfi
%configure --disable-static
make %{?_smp_mflags} V=1

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install

mkdir -p %{buildroot}/%{_datadir}/doc/%{name}-%{version}
for f in `ls %{buildroot}/%{_datadir}/doc/`; do
	if [ -f %{buildroot}/%{_datadir}/doc/$f ]; then
		mv %{buildroot}/%{_datadir}/doc/$f %{buildroot}/%{_datadir}/doc/%{name}-%{version}
	fi
done

# remove static libs and .la files
rm %{buildroot}/%{_libdir}/libwimaxll*.a
find %{buildroot} -type f -name "*.la" -delete -print

%fdupes %{buildroot}%{_includedir}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%{_bindir}/wimaxll-wait-for-state-change
%{_bindir}/wimaxll-rfkill
%{_bindir}/wimaxll-reset
%{_bindir}/wimaxll
%{_bindir}/wimax-tools-version

%files devel
%defattr(-,root,root,-)
%{_includedir}/wimaxll.h
%{_includedir}/wimaxll-version.h
%{_includedir}/wimaxll/
%{_libdir}/pkgconfig/*wimax*
%{_libdir}/libwimaxll*.so

%files -n %{libname}
%defattr(-,root,root,-)
%{_libdir}/libwimaxll*.so.*
%{_libdir}/%{name}-%{version}

%changelog
* Sun Sep  4 2016 rpm@fthiessen.de
- Added build-with-libnl3.patch and versioned-plugindir.patch
- Fixed license field in spec file
* Tue Aug 30 2016 rpm@fthiessen.de
- Use SourceURLs ( https://en.opensuse.org/SourceUrls )
- Fixed build for as much openSUSE versions as possible
  (Dependencies)
* Fri Oct 21 2011 tony@daylessday.org
- Removed static libs and .la files.
* Tue Oct 11 2011 tony@daylessday.org
- Updated to 1.4.5 and fixed build.
* Tue Feb 17 2009 inaky.perez-gonzalez@intel.com
- Update to 1.4.0 (fix detection of non-wimax interfaces)
* Tue Feb 10 2009 inaky.perez-gonzalez@intel.com
- Add dependency to kernel-headrs-wimax to fix lack of kernel-headers
* Tue Feb  3 2009 inaky.perez-gonzalez@intel.com
- Initial (still incomplete and crappy) commit of v1.4.0
